@@ -44,7 +44,6 @@ class SoloModel(BaseEstimator):
 
     .. _SoloModel in documentation:
         https://scikit-uplift.readthedocs.io/en/latest/api/models.html#one-model-with-treatment-as-feature
-
     """
 
     def __init__(self, estimator):
@@ -54,8 +53,7 @@ class SoloModel(BaseEstimator):
         self._type_of_target = None
 
     def fit(self, X, y, treatment, estimator_fit_params=None):
-        """
-        Fit the model according to the given training data.
+        """Fit the model according to the given training data.
 
         For each test example calculate predictions on new set twice: by the first and second models.
         After that calculate uplift as a delta between these predictions.
@@ -63,8 +61,8 @@ class SoloModel(BaseEstimator):
         Return delta of predictions for each example.
 
         Args:
-            X (array-like, shape (n_samples, n_features)): Training vector, where n_samples is the number of samples and
-                n_features is the number of features.
+            X (array-like, shape (n_samples, n_features)): Training vector, where n_samples is the number of
+                samples and n_features is the number of features.
             y (array-like, shape (n_samples,)): Target vector relative to X.
             treatment (array-like, shape (n_samples,)): Binary treatment vector relative to X.
             estimator_fit_params (dict, optional): Parameters to pass to the fit method of the estimator.
@@ -80,7 +78,7 @@ class SoloModel(BaseEstimator):
 
         if isinstance(X, np.ndarray):
             X_mod = np.column_stack((X, treatment))
-        elif isinstance(X, pd.core.frame.DataFrame):
+        elif isinstance(X, pd.DataFrame):
             X_mod = X.assign(treatment=treatment)
         else:
             raise TypeError("Expected numpy.ndarray or pandas.DataFrame in training vector X, got %s" % type(X))
@@ -93,8 +91,7 @@ class SoloModel(BaseEstimator):
         return self
 
     def predict(self, X):
-        """
-        Perform uplift on samples in X.
+        """Perform uplift on samples in X.
 
         Args:
             X (array-like, shape (n_samples, n_features)): Training vector, where n_samples is the number of samples
@@ -106,7 +103,7 @@ class SoloModel(BaseEstimator):
         if isinstance(X, np.ndarray):
             X_mod_trmnt = np.column_stack((X, np.ones(X.shape[0])))
             X_mod_ctrl = np.column_stack((X, np.zeros(X.shape[0])))
-        elif isinstance(X, pd.core.frame.DataFrame):
+        elif isinstance(X, pd.DataFrame):
             X_mod_trmnt = X.assign(treatment=np.ones(X.shape[0]))
             X_mod_ctrl = X.assign(treatment=np.zeros(X.shape[0]))
         else:
@@ -167,8 +164,7 @@ class ClassTransformation(BaseEstimator):
         self._type_of_target = None
 
     def fit(self, X, y, treatment, estimator_fit_params=None):
-        """
-        Fit the model according to the given training data.
+        """Fit the model according to the given training data.
 
         Args:
             X (array-like, shape (n_samples, n_features)): Training vector, where n_samples is the number of samples and
@@ -187,7 +183,6 @@ class ClassTransformation(BaseEstimator):
 
         if self._type_of_target != 'binary':
             raise ValueError("This approach is only suitable for binary classification problem")
-        # TODO: Заменить raise на Warning
         _, treatment_counts = np.unique(treatment, return_counts=True)
         if treatment_counts[0] != treatment_counts[1]:
             warnings.warn(
@@ -204,8 +199,7 @@ class ClassTransformation(BaseEstimator):
         return self
 
     def predict(self, X):
-        """
-        Perform uplift on samples in X.
+        """Perform uplift on samples in X.
 
         Args:
             X (array-like, shape (n_samples, n_features)): Training vector, where n_samples is the number of samples
@@ -220,6 +214,7 @@ class ClassTransformation(BaseEstimator):
 
 class TwoModels(BaseEstimator):
     """aka naïve approach, or difference score method, or double classifier approach.
+
     Fit two separate models: on the treatment data and on the control data.
 
     See more details about `TwoModels in documentation`_.
@@ -227,10 +222,14 @@ class TwoModels(BaseEstimator):
     Args:
         estimator_trmnt (estimator object implementing 'fit'): The object to use to fit the treatment data.
         estimator_ctrl (estimator object implementing 'fit'): The object to use to fit the control data.
-        method (string, ‘vanilla’, ’ddr_control’ or ‘ddr_treatment’, default='vanilla'): Specifies the approach:
-            * ‘vanilla’ - two independent models
-            * ’ddr_control’ -  dependent data representation (First train control estimator)
-            * ’ddr_treatment’ -  dependent data representation (First train treatment estimator)
+        method (string, 'vanilla', 'ddr_control' or 'ddr_treatment', default='vanilla'): Specifies the approach:
+
+            * ``'vanilla'``:
+                Two independent models;
+            * ``'ddr_control'``:
+                Dependent data representation (First train control estimator).
+            * ``'ddr_treatment'``:
+                Dependent data representation (First train treatment estimator).
 
     Attributes:
         trmnt_preds_ (array-like, shape (n_samples, )): Estimator predictions on samples when treatment.
@@ -293,8 +292,7 @@ class TwoModels(BaseEstimator):
             raise ValueError('Control and Treatment estimators should be different objects.')
 
     def fit(self, X, y, treatment, estimator_trmnt_fit_params=None, estimator_ctrl_fit_params=None):
-        """
-        Fit the model according to the given training data.
+        """Fit the model according to the given training data.
 
         For each test example calculate predictions on new set twice: by the first and second models.
         After that calculate uplift as a delta between these predictions.
@@ -302,12 +300,14 @@ class TwoModels(BaseEstimator):
         Return delta of predictions for each example.
 
         Args:
-            X (array-like, shape (n_samples, n_features)): Training vector, where n_samples is the number of samples and
-                n_features is the number of features.
+            X (array-like, shape (n_samples, n_features)): Training vector, where n_samples is the number
+                of samples and n_features is the number of features.
             y (array-like, shape (n_samples,)): Target vector relative to X.
             treatment (array-like, shape (n_samples,)): Binary treatment vector relative to X.
-            estimator_trmnt_fit_params (dict, optional): Parameters to pass to the fit method of the treatment estimator.
-            estimator_ctrl_fit_params (dict, optional): Parameters to pass to the fit method of the control estimator.
+            estimator_trmnt_fit_params (dict, optional): Parameters to pass to the fit method
+                of the treatment estimator.
+            estimator_ctrl_fit_params (dict, optional): Parameters to pass to the fit method
+                of the control estimator.
 
         Returns:
             object: self
@@ -339,11 +339,11 @@ class TwoModels(BaseEstimator):
             if self._type_of_target == 'binary':
                 ddr_control = self.estimator_ctrl.predict_proba(X_trmnt)[:, 1]
             else:
-                ddr_control = self.estimator_ctrl.predict_(X_trmnt)
+                ddr_control = self.estimator_ctrl.predict(X_trmnt)
 
             if isinstance(X_trmnt, np.ndarray):
                 X_trmnt_mod = np.column_stack((X_trmnt, ddr_control))
-            elif isinstance(X_trmnt, pd.core.frame.DataFrame):
+            elif isinstance(X_trmnt, pd.DataFrame):
                 X_trmnt_mod = X_trmnt.assign(ddr_control=ddr_control)
             else:
                 raise TypeError("Expected numpy.ndarray or pandas.DataFrame, got %s" % type(X_trmnt))
@@ -359,11 +359,11 @@ class TwoModels(BaseEstimator):
             if self._type_of_target == 'binary':
                 ddr_treatment = self.estimator_trmnt.predict_proba(X_ctrl)[:, 1]
             else:
-                ddr_treatment = self.estimator_trmnt.predict(X_ctrl)[:, 1]
+                ddr_treatment = self.estimator_trmnt.predict(X_ctrl)
 
             if isinstance(X_ctrl, np.ndarray):
                 X_ctrl_mod = np.column_stack((X_ctrl, ddr_treatment))
-            elif isinstance(X_trmnt, pd.core.frame.DataFrame):
+            elif isinstance(X_trmnt, pd.DataFrame):
                 X_ctrl_mod = X_ctrl.assign(ddr_treatment=ddr_treatment)
             else:
                 raise TypeError("Expected numpy.ndarray or pandas.DataFrame, got %s" % type(X_ctrl))
@@ -375,8 +375,7 @@ class TwoModels(BaseEstimator):
         return self
 
     def predict(self, X):
-        """
-        Perform uplift on samples in X.
+        """Perform uplift on samples in X.
 
         Args:
             X (array-like, shape (n_samples, n_features)): Training vector, where n_samples is the number of samples
@@ -394,25 +393,33 @@ class TwoModels(BaseEstimator):
 
             if isinstance(X, np.ndarray):
                 X_mod = np.column_stack((X, self.ctrl_preds_))
-            elif isinstance(X, pd.core.frame.DataFrame):
+            elif isinstance(X, pd.DataFrame):
                 X_mod = X.assign(ddr_control=self.ctrl_preds_)
             else:
-                raise TypeError("Expected numpy.ndarray or pandas.DataFrame, got %s" % type(X_mod))
-            self.trmnt_preds_ = self.estimator_trmnt.predict_proba(X_mod)[:, 1]
+                raise TypeError("Expected numpy.ndarray or pandas.DataFrame, got %s" % type(X))
+
+            if self._type_of_target == 'binary':
+                self.trmnt_preds_ = self.estimator_trmnt.predict_proba(X_mod)[:, 1]
+            else:
+                self.trmnt_preds_ = self.estimator_trmnt.predict(X_mod)
 
         elif self.method == 'ddr_treatment':
             if self._type_of_target == 'binary':
                 self.trmnt_preds_ = self.estimator_trmnt.predict_proba(X)[:, 1]
             else:
-                self.trmnt_preds_ = self.estimator_trmnt.predict_proba(X)[:, 1]
+                self.trmnt_preds_ = self.estimator_trmnt.predict(X)
 
             if isinstance(X, np.ndarray):
                 X_mod = np.column_stack((X, self.trmnt_preds_))
-            elif isinstance(X, pd.core.frame.DataFrame):
+            elif isinstance(X, pd.DataFrame):
                 X_mod = X.assign(ddr_treatment=self.trmnt_preds_)
             else:
-                raise TypeError("Expected numpy.ndarray or pandas.DataFrame, got %s" % type(X_mod))
-            self.ctrl_preds_ = self.estimator_ctrl.predict_proba(X_mod)[:, 1]
+                raise TypeError("Expected numpy.ndarray or pandas.DataFrame, got %s" % type(X))
+
+            if self._type_of_target == 'binary':
+                self.ctrl_preds_ = self.estimator_ctrl.predict_proba(X_mod)[:, 1]
+            else:
+                self.ctrl_preds_ = self.estimator_ctrl.predict(X_mod)
 
         else:
             if self._type_of_target == 'binary':
